@@ -26,6 +26,7 @@ from .validation import validate_and_convert, convert_to_dict
 from .router import Router
 from .base_router import BaseRouterMixin
 from .cors import CORSConfig, create_cors_config
+from .dependencies import Query, Path, Body, Authenticated
 from .exceptions import (
     APIError,
     ValidationError,
@@ -38,10 +39,19 @@ from .exceptions import (
     InternalServerError,
     ServiceUnavailableError,
 )
-from .error_handlers import error_handler, default_error_handler
+from .error_handlers import error_handler, default_error_handler, ErrorHandler
 from .dev_tools import serve
 
-__version__ = "0.1.5"
+# 認証機能（オプション）
+try:
+    from .auth import DynamoDBAuth
+
+    _AUTH_AVAILABLE = True
+except ImportError:
+    _AUTH_AVAILABLE = False
+    DynamoDBAuth = None  # type: ignore
+
+__version__ = "0.2.17"
 __author__ = "Your Name"
 __email__ = "your.email@example.com"
 
@@ -57,6 +67,10 @@ __all__ = [
     "convert_to_dict",
     "CORSConfig",
     "create_cors_config",
+    "Query",
+    "Path",
+    "Body",
+    "Authenticated",
     "APIError",
     "ValidationError",
     "NotFoundError",
@@ -69,5 +83,10 @@ __all__ = [
     "ServiceUnavailableError",
     "error_handler",
     "default_error_handler",
+    "ErrorHandler",
     "serve",
 ]
+
+# 認証機能が利用可能な場合のみ追加
+if _AUTH_AVAILABLE:
+    __all__.extend(["DynamoDBAuth"])
