@@ -10,10 +10,12 @@ from typing import Dict, Any, Callable, Optional, List, Type, Union
 
 from .request import Request
 from .response import Response
-from .validation import validate_and_convert, convert_to_dict
 from .cors import CORSConfig, create_cors_config
 from .error_handlers import get_global_registry
 from .base_router import BaseRouterMixin
+from .dependency_resolver import resolve_function_dependencies
+from .dependencies import get_function_dependencies
+from .exceptions import ValidationError
 
 # パフォーマンス最適化用キャッシュ
 _SIGNATURE_CACHE: Dict[Callable, inspect.Signature] = {}
@@ -77,15 +79,11 @@ class Route:
         path: str,
         method: str,
         handler: Callable,
-        request_format: Optional[Type] = None,
-        response_format: Optional[Type] = None,
         cors_config: Optional[CORSConfig] = None,
     ):
         self.path = path
         self.method = method.upper()
         self.handler = handler
-        self.request_format = request_format
-        self.response_format = response_format
         self.cors_config = cors_config
         self.path_regex = self._compile_path_regex(path)
 
@@ -157,20 +155,6 @@ class API(BaseRouterMixin):
         """ミドルウェアを追加"""
         self._middleware.append(middleware)
 
-    def error_handler(self, exception_type: Type[Exception]) -> Callable:
-        """エラーハンドラーデコレータ"""
-
-        def decorator(handler_func: Callable) -> Callable:
-            self._error_registry.register(exception_type, handler_func)
-            return handler_func
-
-        return decorator
-
-    def default_error_handler(self, handler_func: Callable) -> Callable:
-        """デフォルトエラーハンドラーデコレータ"""
-        self._error_registry.set_default_handler(handler_func)
-        return handler_func
-
     def _update_route_index(self, route: Route) -> None:
         """ルートを高速検索用インデックスに追加"""
         method = route.method
@@ -189,7 +173,7 @@ class API(BaseRouterMixin):
             self._pattern_routes[method].append(route)
 
     def _rebuild_route_index(self) -> None:
-        """ルートインデックスを再構築（include_router 時に使用）"""
+        """ルートインデックスを再構築（add_router 時に使用）"""
         self._exact_routes.clear()
         self._pattern_routes.clear()
 
@@ -224,9 +208,7 @@ class API(BaseRouterMixin):
             expose_headers=expose_headers,
         )
 
-    def include_router(
-        self, router: Any, prefix: str = "", tags: Optional[List[str]] = None
-    ) -> None:
+    def add_router(self, router: Any, prefix: str = "", tags: Optional[List[str]] = None) -> None:
         """ルーターを追加"""
         from .router import Router
 
@@ -241,8 +223,6 @@ class API(BaseRouterMixin):
                         new_path,
                         route.method,
                         route.handler,
-                        route.request_format,
-                        route.response_format,
                     )
                     new_router.routes.append(new_route)
                 self.routes.extend(new_router.routes)
@@ -252,13 +232,24 @@ class API(BaseRouterMixin):
         # ルートインデックスを再構築
         self._rebuild_route_index()
 
+    def add_error_handler(self, error_handler: Any) -> None:
+        """エラーハンドラーを追加"""
+        from .error_handlers import ErrorHandler
+
+        if isinstance(error_handler, ErrorHandler):
+            # ErrorHandler のレジストリを現在のレジストリにマージ
+            for exception_type, handler in error_handler._registry._handlers.items():
+                self._error_registry.register(exception_type, handler)
+
+            # デフォルトハンドラーも設定
+            if error_handler._registry._default_handler:
+                self._error_registry.set_default_handler(error_handler._registry._default_handler)
+
     def _add_route(
         self,
         path: str,
         method: str,
         handler: Callable,
-        request_format: Optional[Type] = None,
-        response_format: Optional[Type] = None,
         cors: Union[bool, CORSConfig, None] = None,
     ) -> Callable:
         """ルートを追加"""
@@ -269,7 +260,7 @@ class API(BaseRouterMixin):
         elif isinstance(cors, CORSConfig):
             cors_config = cors
 
-        route = Route(path, method, handler, request_format, response_format, cors_config)
+        route = Route(path, method, handler, cors_config)
         self.routes.append(route)
         self._update_route_index(route)
         return handler
@@ -307,24 +298,68 @@ class API(BaseRouterMixin):
         signature = _SIGNATURE_CACHE[handler]
         handler_params = signature.parameters
 
-        # リクエストフォーマットが指定されている場合、リクエストをバリデーション
-        validated_request_data = None
-        if route.request_format:
-            try:
-                request_data = request.json()
-                validated_request_data = validate_and_convert(request_data, route.request_format)
-            except Exception as e:
-                raise ValueError(f"リクエストバリデーションエラー: {str(e)}")
-
-        # 最初の引数が request またはバリデーション済みリクエストかどうかをチェック
+        # 最初の引数が request かどうかをチェック（従来の方式）
         param_names = list(handler_params.keys())
         if param_names and param_names[0] in ["request", "req"]:
             # 従来の方式（request を第一引数に渡す）
-            if route.request_format and validated_request_data:
-                return handler(validated_request_data)
-            else:
-                return handler(request)
+            return handler(request)
 
+        # 新しい依存性注入システムを使用するかチェック
+        dependencies = get_function_dependencies(handler)
+        if dependencies:
+            # 新しい依存性注入システムを使用
+            # 認証が必要な場合は事前に認証処理を実行
+            if getattr(handler, "_auth_required", False):
+                # require_role デコレータのロジックを手動実行
+                self._handle_authentication_for_dependency_injection(handler, request)
+
+            return self._call_handler_with_dependencies(handler, request, path_params)
+        else:
+            # 従来のパラメータ注入システムを使用
+            return self._call_handler_legacy_params(handler, request, path_params, signature)
+
+    def _call_handler_with_dependencies(
+        self, handler: Callable, request: Request, path_params: Optional[Dict[str, str]]
+    ) -> Any:
+        """新しい依存性注入システムでハンドラーを呼び出し"""
+        try:
+            # 認証ユーザーを取得（必要に応じて）
+            authenticated_user = getattr(request, "_authenticated_user", None)
+
+            # 依存性を解決
+            resolved_params = resolve_function_dependencies(
+                handler, request, path_params, authenticated_user
+            )
+
+            # 従来のパラメータも処理（互換性のため）
+            legacy_params = self._get_legacy_params(handler, request, path_params)
+
+            # 依存性注入パラメータを優先し、従来パラメータで補完
+            final_params = {**legacy_params, **resolved_params}
+
+            return handler(**final_params) if final_params else handler()
+
+        except ValidationError:
+            # バリデーションエラーはそのまま再発生させる（エラーハンドラーで処理される）
+            raise
+        except (AttributeError, TypeError, ImportError, KeyError):
+            # 依存性注入固有のエラーのみ従来システムにフォールバック
+            signature = inspect.signature(handler)
+            return self._call_handler_legacy_params(handler, request, path_params, signature)
+        except Exception:
+            # 業務ロジックの例外は依存性注入が完了した後のエラーなのでそのまま再発生
+            raise
+
+    def _call_handler_legacy_params(
+        self,
+        handler: Callable,
+        request: Request,
+        path_params: Optional[Dict[str, str]],
+        signature: inspect.Signature,
+    ) -> Any:
+        """従来のパラメータ注入システムでハンドラーを呼び出し"""
+        handler_params = signature.parameters
+        param_names = list(handler_params.keys())
         call_args: Dict[str, Any] = {}
 
         # パスパラメータをマッチング
@@ -345,19 +380,45 @@ class API(BaseRouterMixin):
                 # 型変換を実行
                 call_args[param_name] = self._convert_param_type(value, param_info)
             elif param_info.default != inspect.Parameter.empty:
-                # デフォルト値を使用
+                # 依存性注入用パラメータ（Body, Query, Path, Authenticated）はスキップ
+                if hasattr(param_info.default, "source"):
+                    continue
+                # 通常のデフォルト値を使用
                 call_args[param_name] = param_info.default
 
         # request 引数がある場合は追加
         if "request" in handler_params:
-            if route.request_format and validated_request_data:
-                call_args["request"] = validated_request_data
-            else:
-                call_args["request"] = request
+            call_args["request"] = request
 
         # キーワード引数として渡す、もしくは引数なしで呼び出し
         return handler(**call_args) if call_args else handler()
 
+    def _get_legacy_params(
+        self, handler: Callable, request: Request, path_params: Optional[Dict[str, str]]
+    ) -> Dict[str, Any]:
+        """従来のパラメータ処理ロジックから基本パラメータを取得"""
+        signature = inspect.signature(handler)
+        handler_params = signature.parameters
+        param_names = list(handler_params.keys())
+        call_args: Dict[str, Any] = {}
+
+        # パスパラメータをマッチング（依存性注入で処理されないもの）
+        if path_params:
+            for param_name in param_names:
+                if param_name in path_params:
+                    # 依存性注入対象でない場合のみ追加
+                    param_info = handler_params.get(param_name)
+                    if param_info and not hasattr(param_info.default, "source"):
+                        call_args[param_name] = self._convert_param_type(
+                            path_params[param_name], param_info
+                        )
+
+        # request 引数がある場合は追加
+        if "request" in handler_params:
+            call_args["request"] = request
+
+        return call_args
+
     def _convert_param_type(self, value: str, param_info: inspect.Parameter) -> Any:
         """パラメータの型アノテーションに基づいて値を変換（最適化版）"""
         converter = _get_type_converter(param_info.annotation)
@@ -404,7 +465,6 @@ class API(BaseRouterMixin):
     def _process_response(self, result: Any, route: Route, request: Request) -> Response:
         """レスポンスを処理"""
         # レスポンスフォーマットバリデーション
-        result = self._validate_response_format(result, route, request)
         if isinstance(result, dict) and "statusCode" in result:
             return Response(result)  # エラーレスポンス
 
@@ -414,7 +474,14 @@ class API(BaseRouterMixin):
         elif isinstance(result, dict):
             response = Response(result)
         else:
-            response = Response({"result": result})
+            # Pydantic Model の場合は辞書に変換
+            if hasattr(result, "model_dump") or hasattr(result, "dict"):
+                # json_encoders を考慮した変換を行う
+                from .validation import convert_to_dict
+
+                response = Response(convert_to_dict(result))
+            else:
+                response = Response({"result": result})
 
         # ミドルウェアを適用
         response = self._apply_middleware(request, response)
@@ -424,30 +491,70 @@ class API(BaseRouterMixin):
 
         return response
 
-    def _validate_response_format(self, result: Any, route: Route, request: Request) -> Any:
-        """レスポンスフォーマットをバリデーション"""
-        if route.response_format and result is not None:
-            try:
-                if isinstance(result, dict):
-                    validated_result = validate_and_convert(result, route.response_format)
-                    return convert_to_dict(validated_result)
-                elif hasattr(result, "__dict__"):
-                    result_dict = result.__dict__ if hasattr(result, "__dict__") else {}
-                    validated_result = validate_and_convert(result_dict, route.response_format)
-                    return convert_to_dict(validated_result)
-            except Exception as e:
-                from .exceptions import InternalServerError
+    def _handle_authentication_for_dependency_injection(
+        self, handler: Callable, request: Request
+    ) -> None:
+        """依存性注入システム用の認証処理"""
+        try:
+            # ハンドラーから認証情報を取得
+            required_roles = getattr(handler, "_required_roles", [])
 
-                validation_error = InternalServerError(
-                    f"レスポンスバリデーションエラー: {str(e)}",
-                    details={"validation_error": str(e)},
-                )
-                error_response = self._error_registry.handle_error(
-                    validation_error, request, self.context
-                )
-                error_response = self._apply_cors_headers(request, error_response, route)
-                return error_response.to_lambda_response()
-        return result
+            # DynamoDBAuth インスタンスを見つける（フレームスタックから探索）
+            import sys
+
+            auth_instance = None
+            frame = sys._getframe()
+
+            while frame and auth_instance is None:
+                frame_locals = frame.f_locals
+                frame_globals = frame.f_globals
+
+                # ローカル変数から auth を探索
+                for var_name, var_value in frame_locals.items():
+                    if hasattr(var_value, "get_authenticated_user") and hasattr(
+                        var_value, "_required_roles"
+                    ):
+                        auth_instance = var_value
+                        break
+
+                # グローバル変数から auth を探索
+                if auth_instance is None:
+                    for var_name, var_value in frame_globals.items():
+                        if hasattr(var_value, "get_authenticated_user") and hasattr(
+                            var_value, "_required_roles"
+                        ):
+                            auth_instance = var_value
+                            break
+
+                frame = frame.f_back  # type: ignore
+
+            if auth_instance is None:
+                # ハンドラーのモジュールから auth をインポート
+                handler_module = sys.modules.get(handler.__module__)
+                if handler_module and hasattr(handler_module, "auth"):
+                    auth_instance = handler_module.auth
+
+            if auth_instance:
+                # 認証ユーザーを取得
+                user = auth_instance.get_authenticated_user(request)
+
+                # ロール権限チェック
+                if auth_instance.is_role_permission:
+                    user_role = getattr(user, "role", None)
+                    if user_role not in required_roles:
+                        from .exceptions import AuthorizationError
+
+                        raise AuthorizationError(f"必要なロール: {', '.join(required_roles)}")
+
+                # 認証ユーザーを request に設定
+                setattr(request, "_authenticated_user", user)
+            else:
+                # 認証インスタンスが見つからない場合はパス（エラーは後で発生する）
+                pass
+
+        except Exception:
+            # 認証エラーをそのまま再発生させる
+            raise
 
     def _handle_global_error(self, error: Exception) -> Dict[str, Any]:
         """グローバルエラーハンドリング"""
