@@ -6,7 +6,7 @@ lambapi.validation モジュールの各機能をテストします。
 
 import pytest
 from dataclasses import dataclass, field
-from typing import List, Optional, Dict, Any, Union
+from typing import List, Optional, Any, Union
 from lambapi.validation import validate_and_convert, convert_to_dict, _convert_value
 
 
@@ -382,6 +382,155 @@ class TestConvertToDict:
         regular_list = [1, 2, 3]
         assert convert_to_dict(regular_list) == regular_list
 
+    def test_datetime_serialization(self):
+        """datetime オブジェクトのシリアライゼーションテスト"""
+        import datetime
+
+        @dataclass
+        class UserWithDates:
+            name: str
+            created_at: datetime.datetime
+            birth_date: datetime.date
+            login_time: datetime.time
+
+        user = UserWithDates(
+            name="Time User",
+            created_at=datetime.datetime(2023, 12, 25, 15, 30, 45),
+            birth_date=datetime.date(1990, 5, 15),
+            login_time=datetime.time(9, 15, 30),
+        )
+        result = convert_to_dict(user)
+
+        expected = {
+            "name": "Time User",
+            "created_at": "2023-12-25T15:30:45",
+            "birth_date": "1990-05-15",
+            "login_time": "09:15:30",
+        }
+        assert result == expected
+
+    def test_uuid_serialization(self):
+        """UUID オブジェクトのシリアライゼーションテスト"""
+        import uuid
+
+        @dataclass
+        class UserWithUUID:
+            name: str
+            user_id: uuid.UUID
+
+        test_uuid = uuid.UUID("550e8400-e29b-41d4-a716-446655440000")
+        user = UserWithUUID(name="UUID User", user_id=test_uuid)
+        result = convert_to_dict(user)
+
+        expected = {"name": "UUID User", "user_id": "550e8400-e29b-41d4-a716-446655440000"}
+        assert result == expected
+
+    def test_decimal_serialization(self):
+        """Decimal オブジェクトのシリアライゼーションテスト"""
+        from decimal import Decimal
+
+        @dataclass
+        class ProductWithPrice:
+            name: str
+            price: Decimal
+
+        product = ProductWithPrice(name="Test Product", price=Decimal("123.45"))
+        result = convert_to_dict(product)
+
+        expected = {"name": "Test Product", "price": "123.45"}
+        assert result == expected
+
+    def test_enum_serialization(self):
+        """Enum オブジェクトのシリアライゼーションテスト"""
+        from enum import Enum
+
+        class Status(Enum):
+            ACTIVE = "active"
+            INACTIVE = "inactive"
+            PENDING = "pending"
+
+        @dataclass
+        class UserWithStatus:
+            name: str
+            status: Status
+
+        user = UserWithStatus(name="Enum User", status=Status.ACTIVE)
+        result = convert_to_dict(user)
+
+        expected = {"name": "Enum User", "status": "active"}
+        assert result == expected
+
+    def test_standalone_datetime_objects(self):
+        """単体の datetime オブジェクトのシリアライゼーションテスト"""
+        import datetime
+
+        dt = datetime.datetime(2023, 12, 25, 15, 30, 45)
+        assert convert_to_dict(dt) == "2023-12-25T15:30:45"
+
+        date = datetime.date(1990, 5, 15)
+        assert convert_to_dict(date) == "1990-05-15"
+
+        time = datetime.time(9, 15, 30)
+        assert convert_to_dict(time) == "09:15:30"
+
+    def test_standalone_special_types(self):
+        """単体の特殊型オブジェクトのシリアライゼーションテスト"""
+        import uuid
+        from decimal import Decimal
+        from enum import Enum
+
+        class Priority(Enum):
+            LOW = 1
+            MEDIUM = 2
+            HIGH = 3
+
+        # UUID
+        test_uuid = uuid.UUID("550e8400-e29b-41d4-a716-446655440000")
+        assert convert_to_dict(test_uuid) == "550e8400-e29b-41d4-a716-446655440000"
+
+        # Decimal
+        decimal_value = Decimal("999.99")
+        assert convert_to_dict(decimal_value) == "999.99"
+
+        # Enum
+        priority = Priority.HIGH
+        assert convert_to_dict(priority) == 3
+
+    def test_mixed_special_types_in_dataclass(self):
+        """データクラス内での複数の特殊型の混在テスト"""
+        import datetime
+        import uuid
+        from decimal import Decimal
+        from enum import Enum
+
+        class OrderStatus(Enum):
+            PENDING = "pending"
+            PROCESSING = "processing"
+            COMPLETED = "completed"
+
+        @dataclass
+        class Order:
+            order_id: uuid.UUID
+            amount: Decimal
+            created_at: datetime.datetime
+            status: OrderStatus
+
+        order = Order(
+            order_id=uuid.UUID("550e8400-e29b-41d4-a716-446655440000"),
+            amount=Decimal("1234.56"),
+            created_at=datetime.datetime(2023, 12, 25, 15, 30, 45),
+            status=OrderStatus.PROCESSING,
+        )
+        result = convert_to_dict(order)
+
+        expected = {
+            "order_id": "550e8400-e29b-41d4-a716-446655440000",
+            "amount": "1234.56",
+            "created_at": "2023-12-25T15:30:45",
+            "status": "processing",
+        }
+        assert result == expected
+
 
 class TestCacheOptimization:
     """キャッシュ最適化のテスト"""
